use fbrfinal.dta

***Appendix 4: N per FE cell
gen one=1
egen n_FEs=total(one), by(FEs)
        . sort FEs
        . quietly by FEs:  gen dup = cond(_N==1,0,_n)
hist n_FEs if dup<=1, width(10) ysize(2) xsize(4) fraction
hist n_FEs if dup<=1 & n_FEs>=50, ysize(2) xsize(2)
hist n_FEs if dup<=1 & n_FEs<50, ysize(2) xsize(2)

***Appendix 5: levels 

***tip
*naive
reg tip X tc, absorb(FEs) robust
nlcom (_b[X]*(xbar/tipbar))
*fdc
reg M X tc, absorb(FEs)
est store st1
reg tip M X tc, absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*(xbar/tipbar)

***tip/price level
*naive
reg tipperc X tc, absorb(FEs) robust
nlcom (_b[X]*(xbar/tippercbar))
*fdc
reg M X tc, absorb(FEs)
est store st1
reg tipperc M X tc, absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*(xbar/tippercbar)

***Appendix 6: excluding fare in controls

***asinh tip
*naive
reg ihs_tip X , absorb(FEs) robust
nlcom _b[X]*xbar*((sqrt(tipbar^2)+1)/tipbar)

*fdc
reg M X , absorb(FEs)
est store st1
reg ihs_tip M X , absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*xbar*((sqrt(tipbar^2)+1)/tipbar)

****tipped
*naive
reg tipped X , absorb(FEs) robust 
nlcom _b[X]*(xbar/tippedbar)

*fdc
reg M X , absorb(FEs)
est store st1
reg tipped M X , absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M]*(xbar/tippedbar))

***asinh tip/price
*naive
reg ihs_tipperc X , absorb(FEs) robust
nlcom _b[X]*xbar*((sqrt(tippercbar^2)+1)/tippercbar)

*fdc
reg M X , absorb(FEs)
est store st1 
reg ihs_tipperc M X , absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*xbar*((sqrt(tippercbar^2)+1)/tippercbar)


***Appendix 7 Omitting fixed effects

***Appendix 6: excluding fare in controls

***asinh tip
*naive
reg ihs_tip X tc,  robust
nlcom _b[X]*xbar*((sqrt(tipbar^2)+1)/tipbar)

*fdc
reg M X tc
est store st1
reg ihs_tip M X tc 
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*xbar*((sqrt(tipbar^2)+1)/tipbar)

****tipped
*naive
reg tipped X tc,  robust 
nlcom _b[X]*(xbar/tippedbar)

*fdc
reg M X tc 
est store st1
reg tipped M X tc
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M]*(xbar/tippedbar))

***asinh tip/price
*naive
reg ihs_tipperc X tc,  robust
nlcom _b[X]*xbar*((sqrt(tippercbar^2)+1)/tippercbar)

*fdc
reg M X tc
est store st1 
reg ihs_tipperc M X tc 
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*xbar*((sqrt(tippercbar^2)+1)/tippercbar)


***Appendix 8: no controls, nonparametric
*naive
reg tipped X
reg ihs_tip X
reg ihs_tipperc X

*fdc
reg M X
reg tipped M X
reg ihs_tip M X
reg ihs_tipperc M X
* to compute fdc multiply conditional means for each dependent variable against the coefficient from first fdc regression

***Appendix 11: exlcuding X in stage 2
*tipped 
reg M X tc, absorb(FEs)
est store st1
reg tipped M tc, absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*(xbar/tippedbar)

*asinh tip
reg M X tc, absorb(FEs)
est store st1
reg ihs_tip M tc, absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*xbar*((sqrt(tipbar^2)+1)/tipbar)

*asinh tip/price
reg M X tc, absorb(FEs)
est store st1
reg ihs_tipperc M tc, absorb(FEs)
est store st2
suest st1 st2, vce(robust)
nlcom [st1_mean]_b[X]*[st2_mean]_b[M]
nlcom ([st1_mean]_b[X]*[st2_mean]_b[M])*xbar*((sqrt(tippercbar^2)+1)/tippercbar)