***Data cleaning
*download data from https://data.cityofchicago.org/Transportation/TNC-2019-Trips/n4i4-nw6t/about_data
*save as "rawdata.csv"
*import may have to occur in chunks of 2 million rows, depending on cpu ability
import delimited "C:\Users\nwwex\OneDrive\Documents\PhD\TNCs-FDC\data\rawdata.csv"

*process time, defined by start time, split up date from clock time from AM/PM
split tripstarttime, parse("")

*clean missing data
drop if pickupcommunityarea==.
drop if dropoffcommunityarea==.
drop if fare==.
drop if tip==.
drop if tripstarttimestamp==""

*create authorization variable X from sharedtripauthorized string
gen X=0
replace X=1 if sharedtripauthorized=="true"
drop if sharedtripauthorized==""
drop if tripspooled==.

*create "actual sharing" M from tripspooled variable 
gen M=0
replace M=1 if tripspooled>1
tab X M
drop if X==0 & M==1

*create two-hour time bins 
gen hr2=.
replace hr2=0 if tripstarttimestamp3=="AM" & (substr(tripstarttimestamp2,1,2)=="12" | substr(tripstarttimestamp2,1,2)=="01")
replace hr2=1 if tripstarttimestamp3=="AM" & (substr(tripstarttimestamp2,1,2)=="02" | substr(tripstarttimestamp2,1,2)=="03")
replace hr2=2 if tripstarttimestamp3=="AM" & (substr(tripstarttimestamp2,1,2)=="04" | substr(tripstarttimestamp2,1,2)=="05")
replace hr2=3 if tripstarttimestamp3=="AM" & (substr(tripstarttimestamp2,1,2)=="06" | substr(tripstarttimestamp2,1,2)=="07")
replace hr2=4 if tripstarttimestamp3=="AM" & (substr(tripstarttimestamp2,1,2)=="08" | substr(tripstarttimestamp2,1,2)=="09")
replace hr2=5 if tripstarttimestamp3=="AM" & (substr(tripstarttimestamp2,1,2)=="10" | substr(tripstarttimestamp2,1,2)=="11")
replace hr2=6 if tripstarttimestamp3=="PM" & (substr(tripstarttimestamp2,1,2)=="12" | substr(tripstarttimestamp2,1,2)=="01")
replace hr2=7 if tripstarttimestamp3=="PM" & (substr(tripstarttimestamp2,1,2)=="02" | substr(tripstarttimestamp2,1,2)=="03")
replace hr2=8 if tripstarttimestamp3=="PM" & (substr(tripstarttimestamp2,1,2)=="04" | substr(tripstarttimestamp2,1,2)=="05")
replace hr2=9 if tripstarttimestamp3=="PM" & (substr(tripstarttimestamp2,1,2)=="06" | substr(tripstarttimestamp2,1,2)=="07")
replace hr2=10 if tripstarttimestamp3=="PM" & (substr(tripstarttimestamp2,1,2)=="08" | substr(tripstarttimestamp2,1,2)=="09")
replace hr2=11 if tripstarttimestamp3=="PM" & (substr(tripstarttimestamp2,1,2)=="10" | substr(tripstarttimestamp2,1,2)=="11")

*create date variable and clean results of tripstarttime parse
encode tripstarttimestamp1, gen(date)
drop tripstarttimestamp1 tripstarttimestamp2 tripstarttimestamp3

*create FEs and delete old variables to save memory
egen FEs=group(pickupcommunityarea dropoffcommunityarea date hr2)
drop pickupcommunityarea dropoffcommunityarea date hr2

*compute total nontip costs because this is the bill riders see after they complete their trip, according to City of Chicago
gen tc=fare+additionalcosts

*construct lhs variables 
gen tipped=0
replace tipped=1 if tip>0
gen ihs_tip=asinh(tip)
gen tipperc=tip/tc
gen ihs_tipperc=asinh(tipperc)

*drop unreasonable total bills 
drop if tc==0
drop if tc>50
drop if tipperc>1
drop if tc<2.5

*saving cleaned dta before regs
save fbrfinal.dta, replace