* The ideal case [Table A1]

clear
drop _all
set obs 100000
set seed 123456789
gen u = rnormal(0,1) // random error
gen treat = 0.5*u + rnormal(0,1) // treatment 
gen z = runiform()
gen mech = z*treat + rnormal(0,1) // mechanism
gen outcome = 0.5*mech + 0.5*u + rnormal(0,1) // outcome - related to treatment via mechansim 

* FDC treatment effect should equal 0.5*0.5 = 0.25 

sureg (mech treat) (outcome mech treat)
nlcom (fdc: [mech]_b[treat]*[outcome]_b[mech]) // Cool, this works!  


reg outcome treat u

reg outcome treat

reg outcome treat mech

reg outcome treat mech u

* Multiple Mechanisms - independent mechanisms [Table A12]

clear
drop _all
set obs 100000
set seed 123456789
gen u = rnormal(0,1) // random error
gen treat = 0.5*u + rnormal(0,1) // treatment
gen mech1 = runiform(0,1)*treat + rnormal(0,1) // First mechanism
gen mech2 = runiform(0,1)*treat + rnormal(0,1) // Second mechanism 
gen outcome = 0.5*mech1 + 0.5*mech2 + 0.5*u +rnormal(0,1) // outcome - related to treatment via 1st and 2nd mechanism

* FDC treatment effect should be equal to 0.5*0.50 + 0.5*0.50 = 0.50

sureg (mech1 treat) (mech2 treat) (outcome mech1 mech2 treat)
nlcom (fdc1: [mech1]_b[treat]*[outcome]_b[mech1]) (fdc2: [mech2]_b[treat]*[outcome]_b[mech2])

nlcom (fdc_sum: [mech1]_b[treat]*[outcome]_b[mech1] + [mech2]_b[treat]*[outcome]_b[mech2]) // Cool, this works!

sureg (mech1 treat) (outcome mech1 treat)
nlcom (fcd_wrong: [mech1]_b[treat]*[outcome]_b[mech1]) // this estimates the "LATE" (i.e. the ATE for those who "comply" to M1

reg outcome treat u // benchmark estimate

reg outcome treat // naive estimate

reg outcome treat mech1 mech2 u // direct effect

reg outcome treat mech1 u // bias

* Multiple Mechanisms - mechanisms on the same causal path [Table A13]

clear
drop _all
set obs 100000
set seed 123456788
gen u = rnormal(0,1) // random error
gen treat = 0.5*u + rnormal(0,1) // treatment
gen mech1 = runiform(0,1)*treat + rnormal(0,1) // First mechanism
gen mech2 = runiform(0,1)*mech1 + rnormal(0,1) // Second mechanism 
gen outcome = 0.5*mech2 + 0.5*u +rnormal(0,1) // outcome - related to treatment via 1st and 2nd mechanism

sureg (mech1 treat) (mech2 treat) (outcome mech1 mech2 treat)
nlcom (fdc1: [mech1]_b[treat]*[outcome]_b[mech1]) (fdc2: [mech2]_b[treat]*[outcome]_b[mech2])

nlcom (fdc_sum: [mech1]_b[treat]*[outcome]_b[mech1] + [mech2]_b[treat]*[outcome]_b[mech2]) // Cool, this works!

sureg (mech1 treat) (outcome mech1 treat)
nlcom (fdc1: [mech1]_b[treat]*[outcome]_b[mech1])

sureg (mech2 treat) (outcome mech2 treat)
nlcom (fdc2: [mech2]_b[treat]*[outcome]_b[mech2])

reg outcome treat u // benchmark

reg outcome treat // naive

* Multiple Mechanisms - one mechanism dependent on the other [Table A14]

clear
drop _all
set obs 100000
set seed 123456788
gen u = rnormal(0,1) // random error
gen treat = 0.5*u + rnormal(0,1) // treatment
gen mech1 = runiform(0,1)*treat + rnormal(0,1) // First mechanism
gen mech2 = runiform(0,1)*treat + runiform(0,1)*mech1 + rnormal(0,1) // Second mechanism 
gen outcome = 0.5*mech2 + 0.5*u +rnormal(0,1) // outcome - related to treatment via 1st and 2nd mechanism

reg outcome treat u // benchmark

reg outcome treat // naive

sureg (mech1 treat) (mech2 treat) (outcome mech1 mech2 treat)
nlcom (fdc1: [mech1]_b[treat]*[outcome]_b[mech1]) (fdc2: [mech2]_b[treat]*[outcome]_b[mech2])

nlcom (fdc_sum: [mech1]_b[treat]*[outcome]_b[mech1] + [mech2]_b[treat]*[outcome]_b[mech2]) // Cool, this works!

sureg (mech1 treat) (outcome mech1 treat)
nlcom (fdc1: [mech1]_b[treat]*[outcome]_b[mech1])

sureg (mech2 treat) (outcome mech2 treat)
nlcom (fdc2: [mech2]_b[treat]*[outcome]_b[mech2])

reg outcome treat u // benchmark

reg outcome treat // naive



* Engodenous Mediator [Figure A5]
clear
drop _all
set obs 100000
set seed 123456789
gen u = rnormal(0,1) // random error
gen treat = 0.5*u + rnormal(0,1) // treatment 
gen mech = runiform()*treat + 2*u + rnormal(0,1) // mechanism
gen outcome = 0.5*mech + 0.5*u +rnormal(0,1) // outcome - related to treatment via mechansim 

* FDC treatment effect should equal 0.5*0.5 = 0.25 

sureg (mech treat) (outcome mech treat)
nlcom (fdc: [mech]_b[treat]*[outcome]_b[mech]) // Now, this doesn't work

reg outcome treat u // benchmark

reg outcome treat // naive

reg outcome mech treat u

** simulation **

* Benchmark estimates
capture program drop fdc

program define fdc, rclass

	// generate data
	clear
	drop _all
	set obs 100000
	*set seed 123456789
	gen u = rnormal(0,1) // random error
	
	local factor = runiform(0,2)
	
	return scalar factor = `factor'
	
	gen treat = 0.5*u + rnormal(0,1) // treatment 
	gen mech = runiform()*treat + `factor'*u + rnormal(0,1) // mechanism
	gen outcome = 0.5*mech + 0.5*u +rnormal(0,1) // outcome - related to treatment via mechansim 
	
	reg outcome treat u // benchmark
	
end

simulate factor = r(factor) benchmark = _b[treat] se_benchmark = _se[treat], reps (1000): fdc

rename factor (benchmark_factor)
gen num = _n

scatter benchmark benchmark_factor

save "benchmark_estimates.dta", replace

* Naive estimates 
capture program drop fdc

program define fdc, rclass

	// generate data
	clear
	drop _all
	set obs 100000
	*set seed 123456789
	gen u = rnormal(0,1) // random error
	
	local factor = runiform(0,2)
	
	return scalar factor = `factor'
	
	gen treat = 0.5*u + rnormal(0,1) // treatment 
	gen mech = runiform()*treat + `factor'*u + rnormal(0,1) // mechanism
	gen outcome = 0.5*mech + 0.5*u +rnormal(0,1) // outcome - related to treatment via mechansim 
	
	reg outcome treat // naive
	
end

simulate factor = r(factor) naive = _b[treat] se_naive = _se[treat], reps (1000): fdc

rename factor (naive_factor)
gen num = _n

scatter naive naive_factor

save "naive_estimates.dta", replace

* FDC estimates 
capture program drop fdc

program define fdc, rclass

	// generate data
	clear
	drop _all
	set obs 100000
	*set seed 123456789
	gen u = rnormal(0,1) // random error
	
	local factor = runiform(0,2)
	
	return scalar factor = `factor'
	
	gen treat = 0.5*u + rnormal(0,1) // treatment 
	gen mech = runiform()*treat + `factor'*u + rnormal(0,1) // mechanism
	gen outcome = 0.5*mech + 0.5*u +rnormal(0,1) // outcome - related to treatment via mechansim 
	
	reg mech treat
	
	return scalar mech_treat = _b[treat]
	return scalar se_mech_treat = _se[treat]
	
	reg outcome mech treat
	
	return scalar outcome_mech = _b[mech]
	return scalar se_outcome_mech = _se[mech]
	
end

simulate factor = r(factor) mech_treat = r(mech_treat) se_mech_treat = r(se_mech_treat) ///
outcome_mech = r(outcome_mech) se_outcome_mech = r(se_outcome_mech), reps (1000): fdc

gen front_door = mech_treat*outcome_mech

rename factor (fdc_factor)
gen num = _n

scatter front_door fdc_factor

save "fdc_estimates.dta", replace

* merge estimates files together
use "fdc_estimates.dta", clear
merge 1:1 num using "naive_estimates.dta"
drop _merge
merge 1:1 num using "benchmark_estimates.dta"
drop _merge

twoway (scatter benchmark benchmark_factor, msymbol(oh) mcolor(gs3)) ///
(scatter naive naive_factor, msymbol(dh) mcolor(midblue)) ///
(scatter front_door fdc_factor, msymbol(th) mcolor(cranberry)), scheme(538bw) ///
ytitle("Estimated Effect") legend(label(1 "Benchmark")) legend(label(2 "Naive")) ///
legend(label(3 "Front-Door")) xtitle("{&Gamma} (Gamma)")


